/**
 * Java Wrapper class for accessing BOMcheck Api
 * @author  Saud Ur Rehman <saud@blubolt.com>
*/

package bomcheck;

import java.io.File;
import java.io.BufferedReader;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.OutputStream;
import java.net.HttpURLConnection;
import java.net.URL;
import java.util.zip.ZipEntry;
import java.util.zip.ZipInputStream;

public class BomcheckApi {
	
	/**
	 * Provides the URL for the API.  The URL is set in the Child wrapper. For example, the Download wrapper would set the URL to https://www.bomcheck.net/api/download.  The Integrate wrapper would set the URL to https://www.bomcheck.net/api/integrate. 
	 * @var string
	 */
	protected String url;
	
	/**
	 * Allows access to the API.  The API key is specified in this Parent wrapper
	 * Text: The Manufacturer's BOMcheck API key.  The Manufacturer must login to their Manufacturer Account on BOMcheck to find out their API key.
	 * @var string
	 */
	protected String apikey;	
	
	/**
	 * FilePath where the response will be saved.  The FilePath is set in the Child wrapper.  Both Child wrappers have a default FilePath setting = c:/tmp/. 
	 * @var string
	 */	
	protected String filePath;

	public BomcheckApi(String url, String filePath)
	{
		this.url = url;
		this.apikey = "2a61a1fcb2aecd6907c6c8e8";
		this.filePath = filePath;
	}
	
	
	/*
	 * SendRequest
	 */
	protected InputStream sendRequest(String query)
	{
		InputStream response = null;
		HttpURLConnection connection = null;
		try {
			String charset = "UTF-8";
			connection = (HttpURLConnection) new URL(this.url).openConnection();
			connection.setDoOutput(true); // Triggers POST.
			connection.setRequestProperty("Accept-Charset", charset);
			connection.setRequestProperty("Content-Type", "application/x-www-form-urlencoded;charset=" + charset);
			OutputStream output = null;
			try {
			     output = connection.getOutputStream();
			     output.write(query.getBytes(charset));
			} finally {
			     if (output != null) try { output.close(); } catch (IOException logOrIgnore) {}
			     try {
			    	 response = connection.getInputStream();
			     } catch(Exception e) {
			    	 if(connection.getResponseCode() == HttpURLConnection.HTTP_BAD_REQUEST) {
			    		 System.out.println(connection.getResponseCode() + " " + connection.getResponseMessage());
			    		 InputStream inputStream = connection.getErrorStream();
			    		 System.out.println(toString(inputStream));
			    	 }else {
			    		 System.out.println("Exception" + e);
			    	 }
			     }
			}
		}
		catch(Exception e){
			System.out.println("Exception" + e);
		}
		return response;
	}
	
	/**
	   * Writes the content of the input stream to a String
	   */
	protected String toString(InputStream inputStream) throws IOException {
	    String string;
	    StringBuilder outputBuilder = new StringBuilder();
	    if (inputStream != null) {
	      BufferedReader reader =
	          new BufferedReader(new InputStreamReader(inputStream));
	      while (null != (string = reader.readLine())) {
	        outputBuilder.append(string).append('\n');
	      }
	    }
	    return outputBuilder.toString();
	}
	
	/**
	   * Writes content to file
	   */
	protected Boolean writeToFile(String path, String content) throws IOException 
	{
		FileOutputStream fop = null;
		File file;

		try {
			file = new File(path);
			fop = new FileOutputStream(file);
			// if file doesnt exists, then create it
			if (!file.exists()) {
				file.createNewFile();
			}
			// get the content in bytes
			byte[] contentInBytes = content.getBytes();
			fop.write(contentInBytes);
			fop.flush();
			fop.close();
		} catch (IOException e) {
			e.printStackTrace();
		} finally {
			try {
				if (fop != null) {
					fop.close();
				}
			} catch (IOException e) {
				e.printStackTrace();
			}
		}
		return true;
	}
	
	/*
	 * Unzip Downloaded data and Save
	 */
	protected Boolean unZipData(String path, InputStream response) {
		try {
			ZipInputStream zin = new ZipInputStream(response);
		    ZipEntry ze = null;
		    while ((ze = zin.getNextEntry()) != null) {
		    	System.out.print("Unzipping " + ze.getName()+ "........");
		    	FileOutputStream fout = new FileOutputStream(path + ze.getName());
		    	for (int c = zin.read(); c != -1; c = zin.read()) {
		    		fout.write(c);
		    	}
		    	zin.closeEntry();
		    	fout.close();
		    	System.out.println("Completed");
		    }
		    zin.close();
		    return true;
		}
		catch(Exception e){
			System.out.println("Exception" + e);
		}
	    return false;
	}
}