/**
 * Java Wrapper class for accessing BOMcheck Api
 * @author  Saud Ur Rehman <saud@blubolt.com>
*/

package bomcheck;

import java.io.InputStream;
import java.net.URLEncoder;

public class BomcheckDownload extends BomcheckApi{
	
	/**
	 * Specifies the format of the data to be returned
	 * CSV or XML
	 * @var string
	 */
	private String format;
	
	/**
	 * Specifies the Class of the IPC 1752A XML to be returned
	 * C, D or checkDThenC for XML, blank for CSV.  If you specify Class D and the FMD < 100% substances declared then BOMcheck will provide a Class D+C XML. If you specify checkDThenC then BOMcheck will check if FMD is available (and if so provide the Class D XML or Class D+C XML) and if not then check if RCD is available (and if so provide the Class C XML). For example, if a supplier has provided 100% FMD for parts A, B, C, D and only RCD data for parts 1, 2, 3, 4 then BOMcheck will provide two XML files for this supplier in the download - a Class D XML for parts A, B, C, D and a Class C XML for parts 1, 2, 3, 4.
	 * @var string
	 */		
	private String formatClass;
	
	/**
	 * Option to select data for particular supplier(s)
	 * Either a single BOMcheck supplier code (DUNS number) or multiple BOMcheck supplier codes (DUNS numbers) separated by comma.  For example: 123456789, 987654321, 222222222. 
	 * @var string
	 */	
	private String supplier;
	
	/**
	 * Option to select data for particular part number(s)
	 * Either a single part number or multiple part numbers separated by comma.  Each part number must be in double quotes.  For example: "ABC123","DEF456","XYZ999".   
	 * @var string
	 */
	private String partNumbers;
	
	/**
	 * Option to select data that has been approved on BOMcheck after a particular Start Date.  
	 * Date must be provided in YYYY-MM-DD format.   
	 * @var Date
	 */
	private String startdate;	
	
			
	public BomcheckDownload(String format, String formatClass,String supplier,String partNumbers, String startdate) {
		super("https://www.bomcheck.net/api/download", "c:/tmp/");// URL must be changed to https://demo.bomcheck.net/api/download if you want to carry out API testing on the demo site. Default FilePath is set to c:/tmp/ and must be changed to the location where you want BOMcheck responses to be saved. 
		this.format = format;
		this.formatClass = formatClass;
		this.supplier = supplier;
		this.partNumbers = partNumbers; 
		this.startdate = startdate;
	}

	/*
	 * Downloads Required Data
	 */
	public Boolean downloadData() {

		try {
			String charset = "UTF-8";
			String query = String.format("apikey=%s&format=%s&class=%s&supplier=%s&partNumbers=%s&startdate=%s", URLEncoder.encode(this.apikey, charset), URLEncoder.encode(this.format, charset),URLEncoder.encode(this.formatClass, charset),URLEncoder.encode(this.supplier, charset),URLEncoder.encode(this.partNumbers, charset),URLEncoder.encode(this.startdate, charset));
			InputStream response = null;
			response = sendRequest(query);
			if(response != null) {
				// Unzip and save file
				if(this.unZipData(this.filePath, response)) {
					System.out.println("Data Downloaded and Unzipped Successfully");
					return true;
				} else {
					System.out.println("Error While UnZipping Files");
				}
			}
		}
		catch(Exception e){
			System.out.println("Exception" + e);
		}
		return true;
	}

	/**
	 * @param args
	 */
	public static void main(String[] args) {
		String format = "XML";
		String formatClass = "";
		String supplier = "687761023";
		String partNumbers = "\"H27U1G8F2BTR-BC\",\"H5PS5162FFR-S6C\"";
		String startdate= ""; //2011-01-01
		BomcheckDownload api = new BomcheckDownload(format,formatClass,supplier,partNumbers,startdate);
		// Download Data
		api.downloadData();
	}
}