/**
 * Java Wraper class for accessing BOMcheck Api
 * @author  Saud Ur Rehman <saud@blubolt.com>
*/

package bomcheck;

import java.io.InputStream;
import java.net.URLEncoder;

public class BomcheckIntegration extends BomcheckApi{
	
	/**
	 * Specifies the integration data that you want to receive.  
	 * Choose one of the following Actions 'listSubstanceCategories','listExemptions','listSuppliers' or 'listCasNumbers' 
	 * @var string
	 */		
	private String action;
	
	/**
	 * Specifies the type of output that BOMcheck will provide
	 * Choose 'file' or 'content'
	 * Default: content
	 * @var string
	 */
	private String output;	
	

	public BomcheckIntegration() {
		super("https://www.bomcheck.net/api/integrate", "c:/tmp/"); //Default FilePath is set to c:/tmp/ and must be changed to the location where you want BOMcheck responses to be saved.
		this.action = "";
		this.output = "content";
	}

	/*
	 * Request Data
	 */
	public Boolean requestData()
	{
		if(this.action.isEmpty())
		{
			System.out.println("Please call one of the actions");
			return false;
		}
		try {
			String charset = "UTF-8";
			String query = String.format("apikey=%s&action=%s&output=%s", URLEncoder.encode(this.apikey, charset), URLEncoder.encode(this.action, charset),URLEncoder.encode(this.output, charset));
			InputStream response = null;
			response = sendRequest(query);
			if(response != null) {
				writeToFile(this.filePath+this.action+".xml", toString(response));
			}
		} catch(Exception e) {
			System.out.println("Exception" + e);
		}
		return true;
	}
	
	/*
	 * List Substance Categories
	 * This Action provides the substance category names and thresholds for each substance category list which is currently included in BOMcheck (i.e. the IPC 1752A substance category lists for RoHS and REACH which are published at http://www.ipc.org/2-18b-committee, the BOMcheck list for Industry Substance Restrictions etc).   
	 * The list contains the CAS numbers which are included in each substance category name.
	 */
	public Boolean listSubstanceCategories()
	{
		this.action = "listSubstanceCategories";
		this.requestData();	
		return true;
	}
	
	/*
	 * List Exemptions
	 * This Action provides the lists of exemptions which are currently included in BOMcheck (i.e. the IPC 1752A exemptions lists for RoHS which are published at http://www.ipc.org/2-18b-committee, the PTC/BOMcheck exemptions for REACH Article 67 etc)
	 */	
	public Boolean listExemptions()
	{
		this.action = "listExemptions";
		this.requestData();
		return true;
	}
	
	/*
	 * List Suppliers
	 * This Action provides the current list of supplier contact details and BOMcheck supplier codes (DUNS numbers) for all suppliers on BOMcheck.
	 */	
	public Boolean listSuppliers()
	{
		this.action = "listSuppliers";
		this.requestData();	
		return true;
	}
	
	/*
	 * List CasNumbers
	 * This Action provides the list of all CAS numbers which are currently included in BOMcheck
	 */	
	public Boolean listCasNumbers()
	{
		this.action = "listCasNumbers";
		this.requestData();
		return true;
	}
	
	/**
	 * @param args
	 */
	public static void main(String[] args)
	{
		BomcheckIntegration bomcheckIntegration = new BomcheckIntegration();

		// Download Data
		bomcheckIntegration.listSubstanceCategories();
		
		bomcheckIntegration.listExemptions();
		
		bomcheckIntegration.listSuppliers();
		
		bomcheckIntegration.listCasNumbers();
	}
}